@@ -117,7 +117,7 @@ class xtable:
         self.__cutwrap = cutwrap
         self.__rowperpage = rowperpage or 2**30
         self.__widthhint = widthhint
-        self.__force_colored = force_color 
+        self.__force_colored = force_colored
         self.__tree = tree
         self.__data = data or list()
         self.__header = header or list()
